@@ -49,7 +49,6 @@ list_all_head()
 {
     atf_set "descr" "Tests that at atf-config prints all expected" \
                     "variables, and not more"
-    atf_set "use.fs" "true"
 }
 list_all_body()
 {
@@ -65,7 +64,6 @@ atf_test_case query_one
 query_one_head()
 {
     atf_set "descr" "Tests that querying a single variable works"
-    atf_set "use.fs" "true"
 }
 query_one_body()
 {
@@ -82,7 +80,6 @@ query_one_terse_head()
 {
     atf_set "descr" "Tests that querying a single variable in terse mode" \
                     "works"
-    atf_set "use.fs" "true"
 }
 query_one_terse_body()
 {
@@ -101,7 +98,6 @@ atf_test_case query_multiple
 query_multiple_head()
 {
     atf_set "descr" "Tests that querying multiple variables works"
-    atf_set "use.fs" "true"
 }
 query_multiple_body()
 {
@@ -116,7 +112,6 @@ query_unknown_head()
 {
     atf_set "descr" "Tests that querying an unknown variable delivers" \
                     "the correct error"
-    atf_set "use.fs" "true"
 }
 query_unknown_body()
 {
@@ -129,7 +124,6 @@ query_mixture_head()
 {
     atf_set "descr" "Tests that querying a known and an unknown variable" \
                     "delivers the correct error"
-    atf_set "use.fs" "true"
 }
 query_mixture_body()
 {
@@ -146,7 +140,6 @@ override_env_head()
 {
     atf_set "descr" "Tests that build-time variables can be overriden" \
                     "through their corresponding environment variables"
-    atf_set "use.fs" "true"
 }
 override_env_body()
 {
@@ -171,36 +164,6 @@ override_env_body()
     done
 }
 
-# XXX: This does not seem to belong here...
-atf_test_case arch
-arch_head()
-{
-    atf_set "descr" "Tests that the current value of atf_arch is correct" \
-                    "for the corresponding atf_machine"
-}
-arch_body()
-{
-    atf_check -s eq:0 -o save:stdout -e empty atf-config -t atf_arch
-    arch=$(cat stdout)
-    atf_check -s eq:0 -o save:stdout -e empty atf-config -t atf_machine
-    machine=$(cat stdout)
-    echo "Machine type ${machine}, architecture ${arch}"
-
-    case ${machine} in
-        i386|i486|i586|i686)
-            exp_arch=i386
-            ;;
-        x86_64)
-            exp_arch=amd64
-            ;;
-        *)
-            exp_arch=${machine}
-    esac
-    echo "Expected architecture ${exp_arch}"
-
-    atf_check_equal ${arch} ${exp_arch}
-}
-
 atf_init_test_cases()
 {
     atf_add_test_case list_all
@@ -212,8 +175,6 @@ atf_init_test_cases()
     atf_add_test_case query_mixture
 
     atf_add_test_case override_env
-
-    atf_add_test_case arch
 }
 
 # vim: syntax=sh:expandtab:shiftwidth=4:softtabstop=4
