@@ -29,6 +29,8 @@
 
 create_atffile()
 {
+    ATF_CONFDIR="$(pwd)"; export ATF_CONFDIR
+
     cat >Atffile <<EOF
 Content-Type: application/X-atf-atffile; version="1"
 
@@ -103,7 +105,6 @@ do_mount() {
 
 atf_test_case main
 main_head() {
-    atf_set "use.fs" "true"
     atf_set "require.user" "root"
 }
 main_body() {
@@ -124,7 +125,6 @@ config_head()
 {
     atf_set "descr" "Tests that the config files are read in the correct" \
                     "order"
-    atf_set "use.fs" "true"
 }
 config_body()
 {
@@ -198,7 +198,6 @@ vflag_head()
 {
     atf_set "descr" "Tests that the -v flag works and that it properly" \
                     "overrides the values in configuration files"
-    atf_set "use.fs" "true"
 }
 vflag_body()
 {
@@ -234,7 +233,6 @@ atffile_head()
 {
     atf_set "descr" "Tests that the variables defined by the Atffile" \
                     "are recognized and that they take the lowest priority"
-    atf_set "use.fs" "true"
 }
 atffile_body()
 {
@@ -272,7 +270,6 @@ atffile_recursive_head()
 {
     atf_set "descr" "Tests that variables defined by an Atffile are not" \
                     "inherited by other Atffiles."
-    atf_set "use.fs" "true"
 }
 atffile_recursive_body()
 {
@@ -296,7 +293,6 @@ atf_test_case fds
 fds_head()
 {
     atf_set "descr" "Tests that all streams are properly captured"
-    atf_set "use.fs" "true"
 }
 fds_body()
 {
@@ -314,7 +310,6 @@ atf_test_case mux_streams
 mux_streams_head()
 {
     atf_set "descr" "Tests for a race condition in stream multiplexing"
-    atf_set "use.fs" "true"
 }
 mux_streams_body()
 {
@@ -331,7 +326,6 @@ expect_head()
 {
     atf_set "descr" "Tests the processing of test case results and the" \
         "expect features"
-    atf_set "use.fs" "true"
 }
 expect_body()
 {
@@ -364,7 +358,6 @@ missing_results_head()
 {
     atf_set "descr" "Ensures that atf-run correctly handles test cases that " \
                     "do not create the results file"
-    atf_set "use.fs" "true"
 }
 missing_results_body()
 {
@@ -387,7 +380,6 @@ broken_results_head()
 {
     atf_set "descr" "Ensures that atf-run reports test programs that" \
                     "provide a bogus results output as broken programs"
-    atf_set "use.fs" "true"
 }
 broken_results_body()
 {
@@ -411,7 +403,6 @@ broken_tp_list_head()
 {
     atf_set "descr" "Ensures that atf-run reports test programs that" \
                     "provide a bogus test case list"
-    atf_set "use.fs" "true"
 }
 broken_tp_list_body()
 {
@@ -443,7 +434,6 @@ zero_tcs_head()
 {
     atf_set "descr" "Ensures that atf-run reports test programs without" \
                     "test cases as errors"
-    atf_set "use.fs" "true"
 }
 zero_tcs_body()
 {
@@ -466,7 +456,6 @@ exit_codes_head()
 {
     atf_set "descr" "Ensures that atf-run reports bogus exit codes for" \
                     "programs correctly"
-    atf_set "use.fs" "true"
 }
 exit_codes_body()
 {
@@ -488,7 +477,6 @@ signaled_head()
 {
     atf_set "descr" "Ensures that atf-run reports test program's crashes" \
                     "correctly regardless of their actual results"
-    atf_set "use.fs" "true"
 }
 signaled_body()
 {
@@ -512,7 +500,6 @@ hooks_head()
 {
     atf_set "descr" "Checks that the default hooks work and that they" \
                     "can be overriden by the user"
-    atf_set "use.fs" "true"
 }
 hooks_body()
 {
@@ -592,7 +579,6 @@ isolation_env_head()
 {
     atf_set "descr" "Tests that atf-run sets a set of environment variables" \
                     "to known sane values"
-    atf_set "use.fs" "true"
 }
 isolation_env_body()
 {
@@ -627,7 +613,6 @@ atf_test_case isolation_home
 isolation_home_head()
 {
     atf_set "descr" "Tests that atf-run sets HOME to a sane and valid value"
-    atf_set "use.fs" "true"
 }
 isolation_home_body()
 {
@@ -640,7 +625,6 @@ atf_test_case isolation_umask
 isolation_umask_head()
 {
     atf_set "descr" "Tests that atf-run sets the umask to a known value"
-    atf_set "use.fs" "true"
 }
 isolation_umask_body()
 {
@@ -656,7 +640,6 @@ cleanup_pass_head()
 {
     atf_set "descr" "Tests that atf-run calls the cleanup routine of the test" \
         "case when the test case result is passed"
-    atf_set "use.fs" "true"
 }
 cleanup_pass_body()
 {
@@ -676,7 +659,6 @@ cleanup_fail_head()
 {
     atf_set "descr" "Tests that atf-run calls the cleanup routine of the test" \
         "case when the test case result is failed"
-    atf_set "use.fs" "true"
 }
 cleanup_fail_body()
 {
@@ -696,7 +678,6 @@ cleanup_skip_head()
 {
     atf_set "descr" "Tests that atf-run calls the cleanup routine of the test" \
         "case when the test case result is skipped"
-    atf_set "use.fs" "true"
 }
 cleanup_skip_body()
 {
@@ -716,7 +697,6 @@ cleanup_curdir_head()
 {
     atf_set "descr" "Tests that atf-run calls the cleanup routine in the same" \
         "work directory as the body so that they can share data"
-    atf_set "use.fs" "true"
 }
 cleanup_curdir_body()
 {
@@ -744,7 +724,6 @@ cleanup_mount_head()
     atf_set "descr" "Tests that the removal algorithm does not cross" \
                     "mount points"
     atf_set "require.user" "root"
-    atf_set "use.fs" "true"
 }
 cleanup_mount_body()
 {
@@ -787,7 +766,6 @@ cleanup_symlink_head()
                     "symlinks, which may live in another device and thus" \
                     "be treated as mount points"
     atf_set "require.user" "root"
-    atf_set "use.fs" "true"
 }
 cleanup_symlink_body()
 {
@@ -823,7 +801,6 @@ atf_test_case require_arch
 require_arch_head()
 {
     atf_set "descr" "Tests that atf-run validates the require.arch property"
-    atf_set "use.fs" "true"
 }
 require_arch_body()
 {
@@ -864,7 +841,6 @@ atf_test_case require_config
 require_config_head()
 {
     atf_set "descr" "Tests that atf-run validates the require.config property"
-    atf_set "use.fs" "true"
 }
 require_config_body()
 {
@@ -883,7 +859,6 @@ atf_test_case require_machine
 require_machine_head()
 {
     atf_set "descr" "Tests that atf-run validates the require.machine property"
-    atf_set "use.fs" "true"
 }
 require_machine_body()
 {
@@ -924,7 +899,6 @@ atf_test_case require_progs
 require_progs_head()
 {
     atf_set "descr" "Tests that atf-run validates the require.progs property"
-    atf_set "use.fs" "true"
 }
 require_progs_body()
 {
@@ -956,7 +930,6 @@ require_user_root_head()
 {
     atf_set "descr" "Tests that atf-run validates the require.user property" \
         "when it is set to 'root'"
-    atf_set "use.fs" "true"
 }
 require_user_root_body()
 {
@@ -977,7 +950,6 @@ require_user_unprivileged_head()
 {
     atf_set "descr" "Tests that atf-run validates the require.user property" \
         "when it is set to 'root'"
-    atf_set "use.fs" "true"
 }
 require_user_unprivileged_body()
 {
@@ -998,7 +970,6 @@ require_user_bad_head()
 {
     atf_set "descr" "Tests that atf-run validates the require.user property" \
         "when it is set to 'root'"
-    atf_set "use.fs" "true"
 }
 require_user_bad_body()
 {
@@ -1013,7 +984,6 @@ atf_test_case timeout
 timeout_head()
 {
     atf_set "descr" "Tests that atf-run kills a test case that times out"
-    atf_set "use.fs" "true"
 }
 timeout_body()
 {
@@ -1033,7 +1003,6 @@ timeout_forkexit_head()
 {
     atf_set "descr" "Tests that atf-run deals gracefully with a test program" \
         "that forks, exits, but the child process hangs"
-    atf_set "use.fs" "true"
 }
 timeout_forkexit_body()
 {
@@ -1047,28 +1016,17 @@ timeout_forkexit_body()
         "been forcibly terminated" || true
 }
 
-atf_test_case use_fs
-use_fs_head()
+atf_test_case ignore_deprecated_use_fs
+ignore_deprecated_use_fs_head()
 {
-    atf_set "descr" "Tests that atf-run correctly handles the use.fs property"
-    atf_set "use.fs" "true"
+    atf_set "descr" "Tests that atf-run ignores the deprecated use.fs property"
 }
-use_fs_body()
+ignore_deprecated_use_fs_body()
 {
     create_helper use_fs
     create_atffile helper
 
-    atf_check -s eq:0 -o ignore -e ignore atf-run \
-        -v allowed=false -v access=false helper
-
-    atf_check -s eq:1 -o ignore -e ignore atf-run \
-        -v allowed=false -v access=true helper
-
-    atf_check -s eq:0 -o ignore -e ignore atf-run \
-        -v allowed=true -v access=false helper
-
-    atf_check -s eq:0 -o ignore -e ignore atf-run \
-        -v allowed=true -v access=true helper
+    atf_check -s eq:0 -o ignore -e ignore atf-run helper
 }
 
 atf_init_test_cases()
@@ -1106,7 +1064,7 @@ atf_init_test_cases()
     atf_add_test_case require_user_bad
     atf_add_test_case timeout
     atf_add_test_case timeout_forkexit
-    atf_add_test_case use_fs
+    atf_add_test_case ignore_deprecated_use_fs
 }
 
 # vim: syntax=sh:expandtab:shiftwidth=4:softtabstop=4
