@@ -37,6 +37,7 @@ extern "C" {
 #include <cstdlib>
 #include <fstream>
 #include <iomanip>
+#include <ios>
 #include <iostream>
 #include <string>
 
@@ -202,7 +203,6 @@ ATF_TEST_CASE_WITH_CLEANUP(cleanup_curdir);
 ATF_TEST_CASE_HEAD(cleanup_curdir)
 {
     set_md_var("descr", "Helper test case for the t_integration test program");
-    set_md_var("use.fs", "true");
 }
 ATF_TEST_CASE_BODY(cleanup_curdir)
 {
@@ -321,12 +321,11 @@ ATF_TEST_CASE(use_fs);
 ATF_TEST_CASE_HEAD(use_fs)
 {
     set_md_var("descr", "Helper test case for the t_integration test program");
-    set_md_var("use.fs", get_config_var("allowed", "not-set"));
+    set_md_var("use.fs", "this-is-deprecated");
 }
 ATF_TEST_CASE_BODY(use_fs)
 {
-    if (get_config_var("access") == "true")
-        touch("test-file");
+    touch("test-file");
 }
 
 // ------------------------------------------------------------------------
