@@ -1,7 +1,7 @@
 //
 // Automated Testing Framework (atf)
 //
-// Copyright (c) 2007, 2008, 2009, 2010 The NetBSD Foundation, Inc.
+// Copyright (c) 2007, 2008, 2009, 2010, 2011 The NetBSD Foundation, Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -50,9 +50,11 @@ extern "C" {
 #include "config.hpp"
 #include "fs.hpp"
 #include "io.hpp"
+#include "requirements.hpp"
 #include "signals.hpp"
 #include "test-program.hpp"
 #include "timer.hpp"
+#include "user.hpp"
 
 namespace impl = atf::atf_run;
 namespace detail = atf::atf_run::detail;
@@ -109,9 +111,6 @@ class metadata_reader : public detail::atf_tp_reader {
 
         if (m_tcs[ident].find("timeout") == m_tcs[ident].end())
             m_tcs[ident].insert(std::make_pair("timeout", "300"));
-
-        if (m_tcs[ident].find("use.fs") == m_tcs[ident].end())
-            m_tcs[ident].insert(std::make_pair("use.fs", "false"));
     }
 
 public:
@@ -267,6 +266,11 @@ run_test_case_child(void* raw_params)
     const test_case_params* params =
         static_cast< const test_case_params* >(raw_params);
 
+    const std::pair< int, int > user = impl::get_required_user(
+        params->metadata, params->config);
+    if (user.first != -1 && user.second != -1)
+        impl::drop_privileges(user);
+
     // The input 'tp' parameter may be relative and become invalid once
     // we change the current working directory.
     const atf::fs::path absolute_executable = params->executable.to_absolute();
@@ -422,12 +426,7 @@ detail::atf_tp_reader::validate_and_insert(const std::string& name,
             throw parse_error(lineno, "The timeout property requires an integer"
                               " value");
     } else if (name == "use.fs") {
-        try {
-            (void)atf::text::to_bool(value);
-        } catch (const std::runtime_error&) {
-            throw parse_error(lineno, "The use.fs property requires a boolean"
-                              " value");
-        }
+        // Deprecated; ignore it.
     } else if (name.size() > 2 && name[0] == 'X' && name[1] == '-') {
         // Any non-empty value is valid.
     } else {
@@ -725,10 +724,9 @@ impl::run_test_case(const atf::fs::path& executable,
         UNREACHABLE;
     }
 
-    ::killpg(child_pid, SIGTERM);
+    ::killpg(child_pid, SIGKILL);
     mux.flush();
     atf::process::status status = child.wait();
-    ::killpg(child_pid, SIGKILL);
 
     std::string reason;
 
