@@ -33,12 +33,14 @@ extern "C" {
 
 #include <limits.h>
 #include <signal.h>
+#include <unistd.h>
 }
 
 #include <cerrno>
 #include <cstdlib>
 #include <cstring>
 #include <fstream>
+#include <ios>
 #include <iostream>
 #include <iterator>
 #include <list>
@@ -184,6 +186,7 @@ static struct name_number {
     { "int", SIGINT },
     { "quit", SIGQUIT },
     { "trap", SIGTRAP },
+    { "abrt", SIGABRT },
     { "kill", SIGKILL },
     { "segv", SIGSEGV },
     { "pipe", SIGPIPE },
@@ -325,7 +328,7 @@ flatten_argv(char* const* argv)
 }
 
 static
-atf::check::check_result
+std::auto_ptr< atf::check::check_result >
 execute(const char* const* argv)
 {
     std::cout << "Executing command [ ";
@@ -338,7 +341,7 @@ execute(const char* const* argv)
 }
 
 static
-atf::check::check_result
+std::auto_ptr< atf::check::check_result >
 execute_with_shell(char* const* argv)
 {
     const std::string cmd = flatten_argv(argv);
@@ -378,7 +381,7 @@ grep_file(const atf::fs::path& path, const std::string& regexp)
     bool found = false;
 
     std::string line;
-    while (!found && std::getline(stream, line).good()) {
+    while (!found && !std::getline(stream, line).fail()) {
         if (atf::text::match(line, regexp))
             found = true;
     }
@@ -802,7 +805,7 @@ atf_check::main(void)
 
     int status = EXIT_FAILURE;
 
-    atf::check::check_result r =
+    std::auto_ptr< atf::check::check_result > r =
         m_xflag ? execute_with_shell(m_argv) : execute(m_argv);
 
     if (m_status_checks.empty())
@@ -817,9 +820,9 @@ atf_check::main(void)
     if (m_stderr_checks.empty())
         m_stderr_checks.push_back(output_check(oc_empty, false, ""));
 
-    if ((run_status_checks(m_status_checks, r) == false) ||
-        (run_output_checks(r, "stderr") == false) ||
-        (run_output_checks(r, "stdout") == false))
+    if ((run_status_checks(m_status_checks, *r) == false) ||
+        (run_output_checks(*r, "stderr") == false) ||
+        (run_output_checks(*r, "stdout") == false))
         status = EXIT_FAILURE;
     else
         status = EXIT_SUCCESS;
